@@ -4,6 +4,8 @@
 import os
 import sys
 import fies
+import time
+import argparse
 from sout import sout
 # 形式変換 (yaml -> equid) [yaml_style_to_equid]
 from .parts import yaml_style_to_equid as y2e
@@ -45,25 +47,38 @@ def compile(
 	# if os.path.exists(output_js_filename): raise Exception("[RangeCSS-Compiler error] output filename already exists.")
 	fies[output_js_filename, "text"] = ret_js_code
 
+# yamlが変更されるたびに自動でコンパイルする
+def loop_compiler(args_dic):
+	pre_t = None	# 最終更新日時
+	while True:
+		now_t = os.path.getmtime(input_filename)	# 最終更新日時
+		if now_t != pre_t:
+			pre_t = now_t
+			print("compiling...")
+			# RangeCSSのyaml帳票をjsに変換 [range_css_compiler]
+			compile(
+				org_yaml_filename = args_dic["input"],
+				output_js_filename = args_dic["output"],	# None指定の場合は自動的にinputファイルから空気を読んだファイル名になる
+			)
+			print("waiting...")
+		# 少し休む
+		time.sleep(0.5)
+
 # コンソールから利用
 def console_command():
 	# コンソール引数
-	arg_ls = sys.argv[1:]
-	# 第一引数で分岐
-	arg_len = len(arg_ls)
-	if arg_len == 0:
-		print("[RangeCSS-Compiler error] Please specify an argument for the command. (Example: rcss compile [filename])")
-		return None
-	if arg_ls[0] == "compile":
-		if arg_len < 2:
-			print("info: Please specify a file name (a yaml file containing the styles) as the second argument.")
-			return None
-		org_yaml_filename = arg_ls[1]
-		output_js_filename = (arg_ls[2] if arg_len >= 3 else None)
+	parser = argparse.ArgumentParser()
+	parser.add_argument("-i", "--input", required = True, help = "Input yaml(.yml) file path")
+	parser.add_argument("-o", "--output", required = False, help = "Output javascript(.js) file path")
+	parser.add_argument("-l", "--loop", required = False, help = "Loop compile mode", acton = "store_true")
+	args_dic = vars(parser.parse_args())
+	# loopオプション有無で分岐
+	if args_dic["loop"] is True:
+		# yamlが変更されるたびに自動でコンパイルする
+		loop_compiler(args_dic)
+	else:
 		# RangeCSSのyaml帳票をjsに変換 [range_css_compiler]
 		compile(
-			org_yaml_filename = org_yaml_filename,
-			output_js_filename = output_js_filename,
+			org_yaml_filename = args_dic["input"],
+			output_js_filename = args_dic["output"],	# None指定の場合は自動的にinputファイルから空気を読んだファイル名になる
 		)
-	else:
-		print("[RangeCSS-Compiler error] unknown command.")
