@@ -96,8 +96,8 @@ def cond_to_qp(cond, var_ls):
 	# 各condを整形
 	left_dic = {"eq": [], "le": []}
 	right_dic = {"eq": [], "le": []}
-	for idx, one_cond in enumerate(cond_ls):
-		show_progress(idx, len(cond_ls))	# 進捗の表示
+	for one_cond in tqdm(cond_ls):
+		# show_progress(idx, len(cond_ls))	# 進捗の表示
 		if one_cond is True: continue
 		# 条件式1つ(equid型)から係数を取り出し
 		cond_type, left, right = one_cond_to_qp(one_cond, var_ls)
